@@ -1,5 +1,5 @@
 def match(command):
-    return command.script == 'test.py' and 'not found' in command.stderr
+    return command.script == 'test.py' and 'not found' in command.output
 
 
 def get_new_command(command):
